#!/bin/bash
#
# author           : P.R. Faasse (faasse@nlr.nl)
# maintainer       : P.R. Faasse
# latest update    : 15-aug-2007
# status           : production
# source location  : www.trolltech.com
# additional files : none
# warning          : this build-file is somewhat non-standard. Qt does not easily support
#                    make install DESTDIR=$dest/$prefix, so it has to be tricked into doing
#                    'the right thing' for ZenWalk
#
# changes log:
# 1) the split of qt into a qt-base and qt-devel package  (1z32)
# 2) -qt-sql-mysql: Stijn (Borromini) loves this.... (1z32)
# 3) removed --no-stl: Rsamurti rightly requested this (42.1)
# 4) moved the qt-mt.pc: bug reported by Tibors (42.2)
# 5) test-code for the symlink in /usr/share/: qt -> qt-3.3.7 (44.1)
#    added QMAKESPEC to the /etc/profile.d files
# 6) removed a 'package-rules-violating' absolute path from doinst.sh
#    (qt-3.3.8 build 46.1)
# 7) changed the icon specification for the designer/assistant/linguist .desktop files
#    post-patched (sed -i) the base package's .dep file to remove mysql from the dependencies.
#    (qt-3.3.8 build 46.2)
# 8) - added icons for use of qt-base when no kde is installed
#    - changed the ld.so inclusion mechanism
#    - applied patches:
#      * one for a format strings vulnerability -> 48.2 build
#      * experimental one for 'strange' charsets support -> 48.0 build... an experimental one...
# 9) rebuilt with new compiler on zenwalk-5.0, source version 3.3.8b
#10) added a ldconfig to the doinst.sh: the one from installpkg is 'too early'

#
# what package is going to be built
#
softname='qt'
softversion='3.3.8b'
#
# trolltech makes a bit of a game of the name of the sources: each subrevision
# seems to suffer from a different tar-file name...
#
sourcearchive="$softname-x11-free-$softversion"
#
# the experimental patch
#
#immod="qt-x11-immodule-unified-qt3.3.8-20070321-gentoo.diff.bz2"

#
# this, with the ') 2>&1 | tee...  redirects the whole stdout/stderr circus to a file
#
(
 
#
# where could you get the source
#
srcurl="ftp://ftp.trolltech.com/qt/source/$sourcearchive.tar.gz"

#
# ZenWalk standard: CPU type and architecture, as well as the
# version number of ZenWalk this package is made for (on?).
#
# arch='i486' -> the compiler uses only 80486 instructions
# cpu='i686'  -> the optimising is done for a PII and above CPU
# packageversion='42.1' means: 
# 42 -> zenwalk-4.2 
# .  -> separator
# 1  -> build number 1
#
arch='i486'
cpu='i686'
packageversion='64.1'

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
#numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
numjobs='-j2'

#
# parameters needed for the build process
#
buildir=$(pwd)
package="$softname-$softversion-$arch-$packageversion"
basepackage="$softname-base-$softversion-$arch-$packageversion"
develpackage="$softname-devel-$softversion-$arch-$packageversion"

#
# dump some context info of the compilation
#
echo "-- context -----"

echo "gcc version"  
gcc --version  
echo "libc version" 
/lib/libc.so.6 

#
# do package-specific settings 
#
# when building Qt we want *no* Qt installed....
# check for an installed Qt
#
echo "-- Qt install check -----"
#
if [ -d /usr/lib/qt ]; then
	#
	echo "Qt is already installed, please de-install Qt first"
	echo "Qt was found in: /usr/lib/qt"
	exit 1 ;
	#
fi
#
if [ -d "/usr/lib/qt-$softversion" ]; then
	#
	echo "Qt is already installed, please de-install Qt first"
	echo "Qt was found in: /usr/lib/qt-$softversion"
	exit 1 ;
	#
fi
#
echo "No Qt found on the machine.. good..."
#

#
# We'll use the SlackWare/ZenWalk database of installed packages: 
# The directory: /var/log/packages keeps a set of all installed 
# ZenWalk packages: one file per installed package
#

cat <<"EOF"
-- build-time dependencies check -----
EOF

depsok=passed

cd /var/log/packages
 
#
# dependencies check
#
for file in \
  mysql \
  sqlite \
; do
 
   #
   # Check the dependency
   #
   if [ -f $file-?.* ] ; then 
      echo "package: $file is installed: `ls -d $file*`: good ...";
   else
      echo "package: $file not found: please install a $file package first";
      depsok=fail
   fi
   #
done

cd $buildir
 
echo "Dependencies check result: $depsok"
#
# check if all dependencies are there
#
if [[ $depsok == passed ]]; then
   unset $depsok;
else
   exit 1;
fi

#
# prepare the build result directory
#
dest="$buildir/$package"
destbase="$buildir/$basepackage"
destdevel="$buildir/$develpackage"
prefix="/usr/lib/$softname-$softversion"
#

#
# clean out the local build-context
#
echo "-- cleanup of the build-tree -----"

rm -rf $dest
rm -rf $destbase
rm -rf $destdevel
#
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $destdevel
mkdir -p $destdevel/install

#
# These two are always needed: 
# applications for the $softname.desktop file, 
# icons for the application icon $softname.png
#
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons
mkdir -p $dest/usr/doc

#
# generate boot-config files
#
echo "-- generate boot-config files -----"

#
# generate some settings-files for qt: warning this
# inplies that a reboot is needed before the installed
# package can be used... 
#
mkdir -p $dest/etc/profile.d
#
# generate /etc/profile.d/qt.sh
#
cat <<"EOF" >$dest/etc/profile.d/qt.sh
#!/bin/sh
# Environment variables for the Qt package.
#
# It's best to use the generic directory to avoid
# compiling in a version-containing path:

if [ -d /usr/lib/qt ]; then
  QTDIR=/usr/lib/qt
else
  # Find the newest Qt directory and set $QTDIR to that:
  for qtd in /usr/lib/qt-* ; do
    if [ -d $qtd ]; then
      QTDIR=$qtd
    fi
  done
fi

if [ ! "$CPLUS_INCLUDE_PATH" = "" ]; then
  CPLUS_INCLUDE_PATH=$QTDIR/include:$CPLUS_INCLUDE_PATH
else
  CPLUS_INCLUDE_PATH=$QTDIR/include
fi

QMAKESPEC=/usr/share/qt/mkspecs/default
MANPATH="$MANPATH:$QTDIR/doc/man"
PATH="$PATH:$QTDIR/bin"
export QTDIR
export CPLUS_INCLUDE_PATH
export MANPATH
EOF
#
chmod a+x $dest/etc/profile.d/qt.sh

#
# generate /etc/profile.d/qt.csh
#
cat <<"EOF" >$dest/etc/profile.d/qt.csh
#!/bin/csh
# Environment path variables for the Qt package:
if ( ! $?QTDIR ) then
    # It's best to use the generic directory to avoid
    # compiling in a version-containing path:
    if ( -d /usr/lib/qt ) then
        setenv QTDIR /usr/lib/qt
    else
        # Find the newest Qt directory and set $QTDIR to that:
        foreach qtd ( /usr/lib/qt-* )
            if ( -d $qtd ) then
                setenv QTDIR $qtd
            endif
        end
    endif
endif
set path = ( $path $QTDIR/bin )
if ( $?CPLUS_INCLUDE_PATH ) then
    setenv CPLUS_INCLUDE_PATH $QTDIR/include:$CPLUS_INCLUDE_PATH
else
    setenv CPLUS_INCLUDE_PATH $QTDIR/include
endif
setenv QMAKESPEC /usr/share/qt/mkspecs/default
setenv MANPATH ${MANPATH}:$QTDIR/doc/man
EOF
#
chmod a+x $dest/etc/profile.d/qt.csh

#
# prepare the directory for the build-file and assorted other 
# user-build related things
#
destsrc="$dest/usr/src/$softname-$softversion"
mkdir -p "$destsrc"
mkdir -p "$destdevel/usr/src/$softname-$softversion"

#
# make a slack-desc file for the base package
#
cat <<EOF > $dest/install/slack-desc
              |-----handy-ruler------------------------------------------------------|
$softname-base: Qt base libraries and tools
$softname-base:
$softname-base: The Qt graphical toolkit, built as 'free' edition
$softname-base: For commercial use you'll need a commercial liscence
$softname-base: see: http://www.trolltech.com
$softname-base: 
$softname-base: this is the 'base' package, containing only the Qt run-time and
$softname-base: 'simple' tools needed to build Qt/KDE applications
$softname-base:
$softname-base: 
$softname-base: 
EOF

#
# make a slack-desc file for the devel package
#
cat <<EOF > $destdevel/install/slack-desc
               |-----handy-ruler------------------------------------------------------|
$softname-devel: Qt development applications and documentation
$softname-devel:
$softname-devel: The Qt graphical toolkit, built as 'free' edition
$softname-devel: For commercial use you'll need a commercial liscence
$softname-devel: see: http://www.trolltech.com
$softname-devel: 
$softname-devel: this is the 'devel' package, containing the Qt development tools
$softname-devel: (assistant/designer/linguist) and the html documentation
$softname-devel: 
$softname-devel: 
$softname-devel: 
EOF

#
# unpack the source archive
#
echo "-- unpack the sources archive -----"

#
# extract the source archive
#
cd $buildir
file=$sourcearchive.tar.*
srcdir="$(basename $file .tar.gz)" 
rm -rf $srcdir
tar xf $file
#
# experiment: immodule experimental patch
#
#echo "-- applying an experimental immodule patch -----"
#bzcat "$immod" | patch -p0
#
cd $srcdir   
#
#echo "-- experimental immodule patch symlinks -----"
##
## from: http://www.freedesktop.org/wiki/Software/ImmoduleManualInstallation
## modified: 
## input -> inputmethod
## '' -> _
## I think the last symlink is going to fail
##
#(
# cd include/
# ln -s ../src/kernel/qinputcontext.h qinputcontext.h
# ln -s ../src/inputmethod/qinputcontextfactory.h qinputcontextfactory.h
# ln -s ../src/inputmethod/qinputcontextplugin.h qinputcontextplugin.h
# cd private/
# ln -s ../../src/inputmethod/qinputcontextinterface_p.h qinputcontextinterface_p.h
# ln -s ../../src/inputmethod/qximinputcontext_p.h qximinputcontext_p.h
#)
#
# end continued experimental stuff
#

#
# make the package-dependent directories
#
mkdir -p $dest/usr/doc/$softname-$softversion
#
# set target permissions
#
chown -R root.root . 
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;

#
# do package-specific settings 
#
echo "-- patching the mkspec for X11R7 -----"

patch -p0 <<"EOF"
*** mkspecs/linux-g++/qmake.conf.old	2006-09-14 01:31:47.403858248 +0200
--- mkspecs/linux-g++/qmake.conf	2006-09-14 01:32:04.158311184 +0200
***************
*** 38,53 ****
  QMAKE_CXXFLAGS_YACC	= $$QMAKE_CFLAGS_YACC
  QMAKE_CXXFLAGS_THREAD	= $$QMAKE_CFLAGS_THREAD
  
  QMAKE_INCDIR		=
  QMAKE_LIBDIR		=
! QMAKE_INCDIR_X11	= /usr/X11R6/include
! QMAKE_LIBDIR_X11	= /usr/X11R6/lib
  QMAKE_INCDIR_QT		= $(QTDIR)/include
  QMAKE_LIBDIR_QT		= $(QTDIR)/lib
! QMAKE_INCDIR_OPENGL	= /usr/X11R6/include
! QMAKE_LIBDIR_OPENGL	= /usr/X11R6/lib
  
  QMAKE_LINK		= g++
  QMAKE_LINK_SHLIB	= g++
  QMAKE_LFLAGS		=
  QMAKE_LFLAGS_RELEASE	=
--- 38,53 ----
  QMAKE_CXXFLAGS_YACC	= $$QMAKE_CFLAGS_YACC
  QMAKE_CXXFLAGS_THREAD	= $$QMAKE_CFLAGS_THREAD
  
  QMAKE_INCDIR		=
  QMAKE_LIBDIR		=
! QMAKE_INCDIR_X11	= /usr/include
! QMAKE_LIBDIR_X11	= /usr/lib
  QMAKE_INCDIR_QT		= $(QTDIR)/include
  QMAKE_LIBDIR_QT		= $(QTDIR)/lib
! QMAKE_INCDIR_OPENGL	= /usr/include
! QMAKE_LIBDIR_OPENGL	= /usr/lib
  
  QMAKE_LINK		= g++
  QMAKE_LINK_SHLIB	= g++
  QMAKE_LFLAGS		=
  QMAKE_LFLAGS_RELEASE	=
EOF

#
# configure package for compilation
#
echo "-- configure -----"

export CFLAGS="-O2 -march=$arch -mtune=$cpu -L $buildir/$srcdir/lib"  
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu -L $buildir/$srcdir/lib"  
export LD_LIBRARY_PATH="$buildir/$srcdir/lib"
export LIBRARY_PATH="$buildir/$srcdir/lib"

#
# the <<EOF and 'yes' are to answer a question:
# the answer 'yes' indicates that we agree to
# build the 'freeware' edition
#
./configure \
  -prefix $prefix \
  -sysconfdir /etc \
  -docdir /usr/doc/$softname-$softversion \
  -datadir /usr/share/$softname-$softversion \
  -release \
  -system-zlib \
  -qt-gif \
  -plugin-sql-mysql \
  -plugin-sql-sqlite \
  -system-libpng \
  -system-libjpeg \
  -plugin-imgfmt-mng \
  -thread \
  -debug \
  -xinerama \
  -no-g++-exceptions \
  -fast \
  <<EOF 
yes
EOF

echo "-- removing the examples from the make proces (i never pack them anyway..) -----"

rm examples/Makefile
cat <<"EOF" >examples/Makefile
all:
EOF

echo "-- patching the mysql pro file to allow for the non-standard location of mysql.h -----"

    patch -p0 <<"EOF"
*** plugins/src/sqldrivers/mysql/mysql.old	2006-10-27 18:27:48.241740328 +0200
--- plugins/src/sqldrivers/mysql/mysql.pro	2006-10-27 18:28:26.495924808 +0200
***************
*** 1,16 ****
--- 1,18 ----
  TEMPLATE = lib
  TARGET	 = qsqlmysql
  
  CONFIG	+= qt plugin
  DESTDIR	 = ../../../sqldrivers
  
+ INCLUDEPATH += /usr/include/mysql
+ 
  HEADERS		= ../../../../src/sql/drivers/mysql/qsql_mysql.h
  SOURCES		= main.cpp \
  		  ../../../../src/sql/drivers/mysql/qsql_mysql.cpp
  
  unix {
  	OBJECTS_DIR = .obj
  
  	!contains( LIBS, .*mysql.* ) {
  	    LIBS    *= -lmysqlclient
  	}
EOF

#
# make package: the Qt configure explicitly requests gmake...
# NB: on a ZenWalk box that is symlinked to 'make'; some difference ;-)
#
echo "-- make -----"
gmake $numjobs  || exit 1

#
# install package to the target directory
#
# This is non-standard in the sense that traditionally, we 
# do a make install DESTDIR=$dest, but for Qt that does not
# work. We are left with the only option to allow Qt to install
# directly into the system-destination directory. That is not
# 'clean' in the sense that the development machine is (badly?)
# affected by the actual Qt build process. We are 'in luck'
# because Qt is quite limited in the number of directories that
# it 'messes up': /usr/lib/qt-$softversion is (as we are currently
# aware..) the only directory that it dumps it's 'mess' in. 
#
echo "-- make install -----"
gmake install || exit 1
	
#
# The make install above has prepared a 'real' install of the qt
# package; remains to a move it and dump it into the package
# itself. A set of 'move' actions can 'do the work there' This does 
# 'zap' the just-installed qt, but for a development machine that 
# must not be all too bad.. Besides: the tgz package is right there 
# ready to re-install the thing... (keeping some fingers crossed 
# at this point ;-)
#
	
#
# move the results into the destination dir
#
echo "-- moving the build-results into the destination directory -----"

#
# i sure hope i've caught them all ;-)
#
mkdir -p "$dest/$prefix" 
(
 cd "$prefix"
 mv * "$dest/$prefix/"
)
rmdir "$prefix"
	
mkdir -p "$dest/usr/doc/$softname-$softversion" 
(
 cd /usr/doc/$softname-$softversion
 mv * "$dest/usr/doc/$softname-$softversion"
)
rmdir /usr/doc/$softname-$softversion
	
#
# one file is moved 'by hand': if i don't then a symlink will be
# made that points to the development directory. That dir will quite
# probably *not* be valid on any target machine ;-)
#
rm "/usr/share/$softname-$softversion/mkspecs/linux-g++/linux-g++"
mv "mkspecs/linux-g++" \
   "/usr/share/$softname-$softversion/mkspecs/linux-g++/linux-g++"

mkdir -p "$dest/usr/share/$softname-$softversion"
(
 cd /usr/share/$softname-$softversion
 mv * "$dest/usr/share/$softname-$softversion"
 cd "$dest/usr/share"
 #
 # make a version-independent symlink /usr/share/qt ->
 # /usr/share/qt-$softversion
 #
 ln -s $softname-$softversion $softname
)
rmdir /usr/share/$softname-$softversion

#
# a rather peculiar file:
#
mkdir -p "$dest/etc"
(
 cd /etc
 mv qt_plugins_3.3rc "$dest/etc/"
)
# no: we're *not* going to rmdir /etc.... ;-)
#
# What should i do with the *contents* of the file: looks like
# gibberish to me.. Some humbug about kde; some plugings stuff...
# Tricky to say the least... We may just have to change this file
# quite a lot before it becomes really usable... This all relates to
# the compilation of the Qt package; but on the target that's just
# what we want to avoid... nb: the 'universal package': only a
# doinst.sh that downloads and compiles the package on the local
# machine... Thus we end up with Gentoo ;-)
# 
# On the other hand: the 'older' versions of Qt did not have this
# file at all; i never saw any effects ;-)
#

#
# add 'default' files to the archive
#
echo "-- adding default files to the archive -----"

#
#
# add 'default' files
#
cp -a \
  AUTHORS COPYING INSTALL NEWS README TODO \
  $dest/usr/doc/$softname-$softversion

echo "-- adding package-rules files to the archive -----"

# 
# as per package rules: add the build-file itself
#
cp "$buildir/build-$softname.sh" \
   "$destsrc/build-$softname.sh"
chmod a+x "$destsrc/build-$softname.sh"

#
# generate an executable script that can be used to get the source
#
cat <<EOF > "$destsrc/getsrc.sh"
# 
# get the source(s) script
#
wget -c $srcurl
EOF
chmod a+x "$destsrc/getsrc.sh"

#
# package the todo file as well
#
cp "$buildir/todo.txt" \
   "$destsrc/todo.txt"

#
# the qt-package needs a symlink to run or $QTDIR will be a mess
# We want to end up with the following directory structure on the target
# machine:
#
# /usr/lib/qt-$softversion: contains the actual qt installed files
# /usr/lib/qt -> /usr/lib/qt-$softversion
#
echo "-- settings a version-independent symlink for qt -----"
(
 cd "$dest/$prefix"
 cd ..
 ln -s qt-$softversion qt
)

#
# generate .desktop files for the relevant executables
#
echo "-- generating .desktop files for the development apps -----"
	mkdir -p "$destdevel/usr/share/applications"

cat <<"EOF" >"$destdevel/usr/share/applications/designer.desktop"
[Desktop Entry]
Name=Designer
Comment=Qt GUI designer
Exec=/usr/lib/qt/bin/designer
Icon=designer
Terminal=false
Type=Application
Categories=Application;Development;
Encoding=UTF-8
StartupNotify=true;
EOF

cat <<"EOF" >"$destdevel/usr/share/applications/linguist.desktop"
[Desktop Entry]
Name=Linguist
Comment=Qt GUI translator
Exec=/usr/lib/qt/bin/linguist
Icon=linguist
Terminal=false
Type=Application
Categories=Application;Development;
Encoding=UTF-8
StartupNotify=true;
EOF

cat <<"EOF" >"$destdevel/usr/share/applications/assistant.desktop"
[Desktop Entry]
Name=Assistant
Comment=Qt GUI designer
Exec=/usr/lib/qt/bin/assistant
Icon=assistant
Terminal=false
Type=Application
Categories=Application;Development;
Encoding=UTF-8
StartupNotify=true;
EOF

echo "-- putting the icons for the assistant, designer and linguist into the devel package -----"
#
# Note: if kdelibs/kdebase is also installed, these icons will get over-written by the kde ones...
# sorry about that, but Qt should also have icons if no kde at all is installed. We do have xcfe
# lovers at ZenWalk, and it simply will not do to leave them completely in the cold.
#
(
 #
 # some vars for the destination dirs
 #
 i128="$destdevel/usr/share/icons/hicolor/128x128/apps"
 i64="$destdevel/usr/share/icons/hicolor/64x64/apps"
 i48="$destdevel/usr/share/icons/hicolor/48x48/apps"
 i32="$destdevel/usr/share/icons/hicolor/32x32/apps"
 i22="$destdevel/usr/share/icons/hicolor/22x22/apps"
 i16="$destdevel/usr/share/icons/hicolor/16x16/apps"
 #
 #
 # make the directories
 #
 mkdir -p "$i32"
 mkdir -p "$i22"
 #
 # the icons are all found based with this bas-directory
 #
 icons="$buildir/$srcdir/tools"
 #
 cp "$icons/assistant/images/assistant.png"  "$i22/assistant.png"
 cp "$icons/assistant/images/designer.png"   "$i22/designer.png"
 cp "$icons/assistant/images/linguist.png"   "$i22/linguist.png"
 #
 # one extra for good measure: a qt icon
 #
 cp "$icons/assistant/images/qt.png"         "$i22/qt.png"
 #
 # the 32x32 icons come from more diverse places
 #
 cp "$icons/assistant/images/appicon.png"                    "$i32/assistant.png"
 cp "$icons/designer/designer/images/designer_appicon.png"   "$i32/designer.png"
 cp "$icons/linguist/linguist/images/appicon.png"            "$i32/linguist.png"
 #
)

#
# package pre-processing
#
echo "-- pre-processing the files for packaging -----"

#
# Uncle_Steve reports that Opera has troubles finding an
# installed qt if the library path "/usr/lib/qt/lib" is not
# present in the file /etc/ld.so.conf. The following part
# of the doinst.sh file should address this. The difficult
# part is to make sure that the path is added only once.
# I don't want to add it multiple times if qt is installed
# more than once... ;-) One snag that remains is that if
# you de-install a qt-package, the line in /etc/ld.so.conf
# will not be removed: uninstallpkg does remove all files 
# that where installed by installpkg, but it does not 'undo'
# any changes to configuration files that installpkg made. 
#

#cat <<"EOF" >>"$dest/install/doinst.sh"
##
## add the entry /usr/lib/qt/lib to the file /etc/ld.so.conf
## but only if this line is not already there
##
#ff=`grep "/usr/lib/qt/lib" etc/ld.so.conf`
##
#if [ ! "$ff" ]; then
#	#
#	echo "Adding the qt directory to the file: /etc/ld.so.conf"
#	echo "/usr/lib/qt/lib" >> etc/ld.so.conf
#	ldconfig
#	#
#fi
##
## remove the temp-var
##
#unset ff
##
## make sure all libraries that are installed are 'registered'
##
#ldconfig
##
#EOF

#
# New mechanism for adding a library path
#
# this has no problems with adding/removing libary paths:
# the /etc/ld.so.conf.d files are all included in ld.so.conf .
# if a package is removed/added, the entry of thios file goes and comes 
# together with this entry...
#
mkdir -p "$dest/etc/ld.so.conf.d"
cat <<"EOF" >"$dest/etc/ld.so.conf.d/qt.conf"
/usr/lib/qt/lib
EOF

#
# added (again..) installpkg also does a ldconfig, but *before*
# running the doinst script. The result: the re-generated 
# symlink to /usr/lib/qt/lib is not picked up.
#
cat <<"EOF" >>"$dest/install/doinst.sh"
#
# make sure all libraries that are installed are 'registered'
#
ldconfig
#
EOF
#
# post-build processing: 
# - strip executables 
# - compress man-pages
#
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  for mandir in $(find . -name man -type d) ; do
    if [ -d $mandir ]; then
      ( cd $mandir
        find . -type f -name "*.?" -exec gzip -9 {} \;
      )
    fi
  done
)

#
# set the ownership of the result
#
echo "-- setting ownership to root.root -----"

#
chown -R root.root $dest/usr

#
# now, we're going to split the result into two packages: the qt-base
# and qt-devel package. 
#

echo "-- splitting the files into a base and development package -----"

(
 #
 # rename the $dest dir to $destbase
 #
 cd $buildir
 mv $dest $destbase

 #
 # remember: current dir = $destbase
 #
 cd $destbase
 #
 # the contents of usr/src i want in both packages
 #
 mkdir -p $destdevel/usr/src
 cp -R usr/src/* $destdevel/usr/src/
 #
 # usr/doc goes to devel
 #
 mkdir -p $destdevel/usr
 mv usr/doc $destdevel/usr
 #
 # the development apps (designer/assistant/linguist) go to devel
 #
 mkdir -p $destdevel/usr/lib/qt-$softversion/bin
 mv usr/lib/qt-$softversion/bin/assistant $destdevel/usr/lib/qt-$softversion/bin
 mv usr/lib/qt-$softversion/bin/designer $destdevel/usr/lib/qt-$softversion/bin
 mv usr/lib/qt-$softversion/bin/linguist $destdevel/usr/lib/qt-$softversion/bin
 #
 # the libraries: the development ones to devel, the rest remains in base
 #
 mkdir -p $destdevel/usr/lib/qt-$softversion/lib
 mv usr/lib/qt-$softversion/lib/libdesignercore* $destdevel/usr/lib/qt-$softversion/lib
 mv usr/lib/qt-$softversion/lib/libqassistant* $destdevel/usr/lib/qt-$softversion/lib
 #
 # Tibors' change: move /usr/lib/qt-3.3.7/lib/pkgconfig/qt-mt.pc
 #                   to /usr/lib/pkgconfig/qt-mt.pc
 #
 # i moved the entire directory: the qt-mt.pc is the only file there...
 #
 mv usr/lib/qt-$softversion/lib/pkgconfig usr/lib/
 #
 #
 echo "-- patching the qt-mt.pc file to remove the version-dependent path -----"
 (
  cd usr/lib/pkgconfig
  patch -p0 qt-mt.pc <<EOF
1c1
< prefix=/usr/lib/qt-$softversion
---
> prefix=/usr/lib/qt
EOF

 )

)


#
# packaging
#
echo "-- packaging/md5/dep file creation -----"
#
# we have two packages to create, and i want them to end up in $buildir
#
(
 cd $buildir/$basepackage
 makepkg -p -l y -c n $buildir/$basepackage.txz
 cd $buildir/$develpackage
 makepkg -p -l y -c n $buildir/$develpackage.txz
)
#
# compute the md5-sums of the packages
#
(
 cd $buildir
 md5sum $develpackage.txz >$develpackage.md5
 md5sum $basepackage.txz >$basepackage.md5
 EXCLUDE=mysql,libmysqlclient requiredbuilder -z $develpackage.txz >$develpackage.dep
 EXCLUDE=mysql,libmysqlclient requiredbuilder -z $basepackage.txz >$basepackage.dep
 #
)

#
# i want the entire log...
#
) 2>&1 | tee "$softname-$softversion-info.txt"
